@@ -2,13 +2,15 @@ import json
 
 import requests
 
+from rainiee_data.utils import upass
+
 
 class LoginApi:
     def __init__(self, username, password, timeout=15):
         self.__timeout = timeout
         self.__username = username
         self.__password = password
-        self.__login_url = 'https://data.rainiee.com/api/v1.0/api-token-auth'
+        self.__login_url = upass.get_host() + '/api/v1.0/api-token-auth'
 
     def login(self):
         res = requests.get(self.__login_url, params={'username': self.__username, 'password': self.__password},
